@@ -1,12 +1,11 @@
 import argparse
-import os
 import logging
 import inspect
 import sys
-from typing import List, Tuple, Optional, Dict, Sequence, Iterable, Iterator
+from typing import List, Tuple, Optional, Dict, Sequence, Iterable, Iterator, Union
 from pathlib import Path
 from datetime import datetime
-from subprocess import check_call
+from .compat import check_call, register_argparse_extend_action_in_pre_py38
 from tempfile import TemporaryDirectory
 
 
@@ -19,7 +18,7 @@ from .dump import visits_to_sqlite
 from .extract import extract_visits, make_filter
 
 
-def iter_all_visits() -> Iterator[Res[DbVisit]]:
+def iter_all_visits(sources_subset: Iterable[Union[str, int]]=()) -> Iterator[Res[DbVisit]]:
     cfg = config.get()
     output_dir = cfg.output_dir
     # not sure if belongs here??
@@ -29,8 +28,22 @@ def iter_all_visits() -> Iterator[Res[DbVisit]]:
 
     hook = cfg.hook
 
-    indexers = cfg.sources
-    for idx in indexers:
+    indexers = list(cfg.sources)
+
+    is_subset_sources = bool(sources_subset)
+    if is_subset_sources:
+        sources_subset = set(sources_subset)
+
+    for i, idx in enumerate(indexers):
+        name = getattr(idx, "name", None)
+        if name and is_subset_sources:
+            matched = name in sources_subset or i in sources_subset
+            if matched:
+                sources_subset -= {i, name}  # type: ignore
+            else:
+                logger.debug("skipping '%s' not in --sources.", name)
+                continue
+
         if isinstance(idx, Exception):
             yield idx
             continue
@@ -45,12 +58,15 @@ def iter_all_visits() -> Iterator[Res[DbVisit]]:
                 except Exception as e:
                     yield e
 
+    if sources_subset:
+        logger.warning("unknown --sources: %s", ", ".join(repr(i) for i in sources_subset))
 
-def _do_index(dry: bool=False) -> Iterable[Exception]:
+
+def _do_index(dry: bool=False, sources_subset: Iterable[Union[str, int]]=(), overwrite_db=False) -> Iterable[Exception]:
     # also keep & return errors for further display
     errors: List[Exception] = []
-    def it():
-        for v in iter_all_visits():
+    def it() -> Iterable[Res[DbVisit]]:
+        for v in iter_all_visits(sources_subset):
             if isinstance(v, Exception):
                 errors.append(v)
             yield v
@@ -61,17 +77,22 @@ def _do_index(dry: bool=False) -> Iterable[Exception]:
         for v in res:
             print(v)
     else:
-        dump_errors = visits_to_sqlite(it())
+        dump_errors = visits_to_sqlite(it(), overwrite_db=overwrite_db)
         for e in dump_errors:
             logger.exception(e)
             errors.append(e)
     return errors
 
 
-def do_index(config_file: Path, dry: bool=False) -> None:
+def do_index(
+        config_file: Path,
+        dry: bool=False,
+        sources_subset: Iterable[Union[str, int]]=(),
+        overwrite_db: bool=False,
+    ) -> None:
     config.load_from(config_file) # meh.. should be cleaner
     try:
-        errors = list(_do_index(dry=dry))
+        errors = list(_do_index(dry=dry, sources_subset=sources_subset, overwrite_db=overwrite_db))
     finally:
         config.reset()
     if len(errors) > 0:
@@ -92,21 +113,29 @@ def demo_sources():
             return getattr(module, 'index')
         return inner
 
-    return {
-        # TODO ugh, this runs against merged db
-        # 'chrome' : browser.chrome,
-        # 'firefox': browser.firefox,
-        'auto'    : lazy('auto'),
-        # TODO org mode
-
-        'takeout' : lazy('takeout'),
-        'telegram': lazy('telegram'),
-        'guess'   : lazy('guess')
-    }
+    res = {}
+    import ast
+    import promnesia.sources
+    for p in promnesia.sources.__path__: # type: ignore[attr-defined] # should be present
+        for x in sorted(Path(p).glob('*.py')):
+            a = ast.parse(x.read_text())
+            candidates = [c for c in a.body if getattr(c, 'name', None) == 'index']
+            if len(candidates) > 0:
+                res[x.stem] = lazy(x.stem)
+    return res
 
 
-
-def do_demo(*, index_as: str, params: Sequence[str], port: Optional[str], config_file: Optional[Path], name='demo'):
+def do_demo(
+        *,
+        index_as: str,
+        params: Sequence[str],
+        port: Optional[str],
+        config_file: Optional[Path],
+        dry: bool=False,
+        name: str='demo',
+        sources_subset: Iterable[Union[str, int]]=(),
+        overwrite_db: bool=False,
+    ) -> None:
     from pprint import pprint
     with TemporaryDirectory() as tdir:
         outdir = Path(tdir)
@@ -122,7 +151,7 @@ def do_demo(*, index_as: str, params: Sequence[str], port: Optional[str], config
             )
             config.instance = cfg
 
-        errors = list(_do_index())
+        errors = list(_do_index(dry=dry, sources_subset=sources_subset, overwrite_db=overwrite_db))
         if len(errors) > 0:
             logger.error('%d errors during indexing (see logs above for backtraces)', len(errors))
         for e in errors:
@@ -152,7 +181,7 @@ def read_example_config() -> str:
     return inspect.getsource(config_example)
 
 
-def config_create(args) -> None:
+def config_create(args: argparse.Namespace) -> None:
     cfg = user_config_file()
     cfgdir = cfg.parent
     if cfgdir.exists():
@@ -165,8 +194,8 @@ def config_create(args) -> None:
         logger.info("Created a stub config in '%s'. Edit it to tune to your liking. (see https://github.com/karlicoss/promnesia#setup for more info)", cfg)
 
 
-def config_check(args) -> None:
-    cfg = args.config
+def config_check(args: argparse.Namespace) -> None:
+    cfg: Path = args.config
     errors = list(_config_check(cfg))
     if len(errors) == 0:
         logger.info('OK')
@@ -176,11 +205,11 @@ def config_check(args) -> None:
 
 
 def _config_check(cfg: Path) -> Iterable[Exception]:
-    from subprocess import run
+    from .compat import run
 
     logger.info('config: %s', cfg)
 
-    def check(cmd):
+    def check(cmd) -> Iterable[Exception]:
         logger.debug(' '.join(map(str, cmd)))
         res = run(cmd)
         if res.returncode > 0:
@@ -212,7 +241,7 @@ def _config_check(cfg: Path) -> Iterable[Exception]:
     yield from check([sys.executable, cfg])
 
 
-def cli_doctor_db(args) -> None:
+def cli_doctor_db(args: argparse.Namespace) -> None:
     # todo could fallback to 'sqlite3 <db> .dump'?
     config.load_from(args.config) # TODO meh
     db = config.get().db
@@ -233,11 +262,11 @@ def cli_doctor_db(args) -> None:
         sys.exit(1)
     cmd = [bro, str(db)]
     logger.debug(f'Running {cmd}')
-    from subprocess import Popen
+    from .compat import Popen
     Popen(cmd)
 
 
-def cli_doctor_server(args) -> None:
+def cli_doctor_server(args: argparse.Namespace) -> None:
     port = args.port
     endpoint = f'http://localhost:{port}/status'
     cmd = ['curl', endpoint]
@@ -247,15 +276,47 @@ def cli_doctor_server(args) -> None:
     logger.info('You should see the database path and version above!')
 
 
+def _ordinal_or_name(s: str) -> Union[str, int]:
+    try:
+        s = int(s)  # type: ignore
+    except ValueError:
+        pass
+    return s
+
+
 def main() -> None:
     # TODO longer, literate description?
 
+    def add_index_args(parser: argparse.ArgumentParser, default_config_path: PathIsh=None) -> None:
+        """
+        :param default_config_path:
+            if not given, all :func:`demo_sources()` are run
+        """
+        register_argparse_extend_action_in_pre_py38(parser)
+        parser.add_argument('--config', type=Path, default=default_config_path, help='Config path')
+        parser.add_argument('--dry', action='store_true', help="Dry run, won't touch the database, only print the results out")
+        parser.add_argument(
+            '--sources',
+            required=False,
+            action="extend",
+            nargs="+",
+            type=_ordinal_or_name,
+            metavar="SOURCE",
+            help="Source names (or their 0-indexed position) to index.",
+        )
+        parser.add_argument(
+            '--overwrite',
+            required=False,
+            action="store_true",
+            help="Empty db before populating it with newly indexed visits."
+            "  If interrupted, db is left untouched."
+        )
+
     F = lambda prog: argparse.ArgumentDefaultsHelpFormatter(prog, width=120)
     p = argparse.ArgumentParser(formatter_class=F) # type: ignore
     subp = p.add_subparsers(dest='mode', )
     ep = subp.add_parser('index', help='Create/update the link database', formatter_class=F)
-    ep.add_argument('--config', type=Path, default=default_config_path(), help='Config path')
-    ep.add_argument('--dry', action='store_true', help="Dry run, won't touch the database, only print the results out")
+    add_index_args(ep, default_config_path())
     # TODO use some way to override or provide config only via cmdline?
     ep.add_argument('--intermediate', required=False, help="Used for development, you don't need it")
 
@@ -271,13 +332,13 @@ def main() -> None:
     ap.add_argument('--name', type=str, default='demo'               , help='Set custom source name')
     add_port_arg(ap)
     ap.add_argument('--no-serve', action='store_const', const=None, dest='port', help='Pass to only index without running server')
-    ap.add_argument('--config', type=Path, required=False            , help='Config to run against. If omitted, will use empty base config')
     ap.add_argument(
         '--as',
         choices=list(sorted(demo_sources().keys())),
         default='guess',
-        help='Index the path as',
+        help='Promnesia source to index as (see https://github.com/karlicoss/promnesia/tree/master/src/promnesia/sources for the full list)',
     )
+    add_index_args(ap)
     ap.add_argument('params', nargs='*', help='Optional extra params for the indexer')
 
     isp = subp.add_parser('install-server', help='Install server as a systemd service (for autostart)', formatter_class=F)
@@ -311,19 +372,35 @@ def main() -> None:
         p.print_help(sys.stderr)
         sys.exit(1)
 
+    logger.info("CLI args: %s", args)
+
     # TODO maybe, it's better for server to compute intermediate represetnation?
     # the only downside is storage. dunno.
     # worst case -- could use database?
 
     with get_tmpdir() as tdir: # TODO??
         if args.mode == 'index':
-             do_index(config_file=args.config, dry=args.dry)
+            do_index(
+                config_file=args.config,
+                dry=args.dry,
+                sources_subset=args.sources,
+                overwrite_db=args.overwrite,
+            )
         elif args.mode == 'serve':
             server.run(args)
         elif args.mode == 'demo':
             # TODO not sure if 'as' is that useful
             # something like Telegram/Takeout is too hard to setup to justify adhoc mode like this?
-            do_demo(index_as=getattr(args, 'as'), params=args.params, port=args.port, config_file=args.config, name=args.name)
+            do_demo(
+                index_as=getattr(args, 'as'),
+                params=args.params,
+                port=args.port,
+                config_file=args.config,
+                dry=args.dry,
+                name=args.name,
+                sources_subset=args.sources,
+                overwrite_db=args.overwrite,
+                )
         elif args.mode == 'install-server': # todo rename to 'autostart' or something?
             install_server.install(args)
         elif args.mode == 'config':
