@@ -1,10 +1,11 @@
 from collections.abc import Sized
 from datetime import datetime, date
 import os
-from typing import NamedTuple, Set, Iterable, Dict, TypeVar, Callable, List, Optional, Union, Any, Collection, Sequence, Tuple, TypeVar
+from typing import NamedTuple, Set, Iterable, Dict, TypeVar, Callable, List, Optional, Union, Any, Collection, Sequence, Tuple, TypeVar, TYPE_CHECKING
 from pathlib import Path
 from glob import glob
 import itertools
+from more_itertools import intersperse
 import logging
 from functools import lru_cache
 import shutil
@@ -14,6 +15,8 @@ import warnings
 from .cannon import canonify
 
 
+_is_windows = os.name == 'nt'
+
 T = TypeVar('T')
 Res = Union[T, Exception]
 
@@ -35,7 +38,7 @@ class Loc(NamedTuple):
         return cls(title=title, href=href)
 
     @classmethod
-    def file(cls, path: PathIsh, line: Optional[int]=None, relative_to: Optional[Path]=None):
+    def file(cls, path: PathIsh, line: Optional[int]=None, relative_to: Optional[Path]=None) -> 'Loc':
         lstr = '' if line is None else f':{line}'
         # todo loc should be url encoded? dunno.
         # or use line=? eh. I don't know. Just ask in issues.
@@ -70,7 +73,7 @@ class Loc(NamedTuple):
 @lru_cache(1)
 def _detect_mime_handler() -> str:
     def exists(what: str) -> bool:
-        from subprocess import run, PIPE
+        from .compat import run, PIPE
         try:
             r = run(f'xdg-mime query default x-scheme-handler/{what}'.split(), stdout=PIPE)
         except FileNotFoundError:
@@ -140,6 +143,7 @@ class DbVisit(NamedTuple):
     @staticmethod
     def make(p: Visit, src: SourceName) -> Res['DbVisit']:
         try:
+            # hmm, mypy gets a bit confused here.. presumably because datetime is always datetime (but date is not datetime)
             if isinstance(p.dt, datetime):
                 dt = p.dt
             elif isinstance(p.dt, date):
@@ -178,10 +182,11 @@ def get_logger() -> logging.Logger:
 
 
 
+import tempfile
 # kinda singleton
 @lru_cache(1)
-def get_tmpdir():
-    import tempfile
+def get_tmpdir() -> tempfile.TemporaryDirectory:
+    # todo use appdirs?
     tdir = tempfile.TemporaryDirectory(suffix="promnesia")
     return tdir
 
@@ -230,12 +235,24 @@ def from_epoch(ts: int) -> datetime:
     return datetime.fromtimestamp(ts, tz=pytz.utc)
 
 
+def join_tags(tags: Iterable[str]) -> str:
+    """
+    Append `#` in fron of each tag and joins them with a space in between
+
+    >>> join_tags(["foo", "bar"])
+    '#foo #bar'
+    >>> join_tags(["", " ", None])
+    ''
+    """
+    return " ".join(f"#{t}" for t in tags if t and t.strip())
+
+
 class PathWithMtime(NamedTuple):
     path: Path
     mtime: float
 
     @classmethod
-    def make(cls, p: Path):
+    def make(cls, p: Path) -> 'PathWithMtime':
         return cls(
             path=p,
             mtime=p.stat().st_mtime,
@@ -243,7 +260,7 @@ class PathWithMtime(NamedTuple):
 
 
 # todo not sure about this...
-def _guess_name(thing) -> str:
+def _guess_name(thing: Any) -> str:
     from types import ModuleType
     guess = ''
     if isinstance(thing, ModuleType):
@@ -258,7 +275,7 @@ def _guess_name(thing) -> str:
     return guess
 
 
-def _get_index_function(thing):
+def _get_index_function(thing: Any):
     # see config_tests
     # not sure about this
     if hasattr(thing, 'index'):
@@ -342,21 +359,31 @@ def default_cache_dir() -> Path:
 # make it lazy, otherwise it might crash on module import (e.g. on Windows)
 # ideally would be nice to fix it properly https://github.com/ahupp/python-magic#windows
 @lru_cache(1)
-def _magic():
+def _magic() -> Callable[[PathIsh], Optional[str]]:
     logger = get_logger()
     try:
         import magic # type: ignore
-    except ModuleNotFoundError as me:
-        logger.exception(me)
-        msg = "python-magic is not detected. It's recommended for better file type detection (pip3 install --user python-magic). See https://github.com/ahupp/python-magic#installation"
-        logger.warning(msg)
-        warnings.warn(msg)
-        return lambda path: None # stub
+    except Exception as e:
+        logger.exception(e)
+        defensive_msg: Optional[str] = None
+        if isinstance(e, ModuleNotFoundError) and e.name == 'magic':
+            defensive_msg = "python-magic is not detected. It's recommended for better file type detection (pip3 install --user python-magic). See https://github.com/ahupp/python-magic#installation"
+        elif isinstance(e, ImportError):
+            emsg = getattr(e, 'msg', '') # make mypy happy
+            if 'failed to find libmagic' in emsg: # probably the actual library is missing?...
+                defensive_msg = "couldn't import magic. See https://github.com/ahupp/python-magic#installation"
+        if defensive_msg is not None:
+            logger.warning(defensive_msg)
+            warnings.warn(defensive_msg)
+            return lambda path: None # stub
+        else:
+            raise e
     else:
         mm = magic.Magic(mime=True)
         return mm.from_file
 
 
+# todo annoying... can't return module in mypy
 @lru_cache(1)
 def _mimetypes():
     import mimetypes
@@ -376,18 +403,42 @@ def mime(path: PathIsh) -> Optional[str]:
     return magic(ps)
 
 
-def find_args(root: Path, follow: bool) -> List[str]:
+def find_args(root: Path, follow: bool, ignore: List[str]=[]) -> List[str]:
+    prune_dir_args = []
+    ignore_file_args = []
+    if ignore:
+        # -name {name} for all the file/directories in ignore
+        ignore_names = [['-name', n] for n in ignore]
+        # OR (-o) all the names together and flatten
+        ignore_names_l = list(itertools.chain(*intersperse(['-o'], ignore_names)))
+        # Prune all of those directories, and make the entire clause evaluate to false
+        # (so that it doesn't match anything and make find print)
+        prune_dir_args = ['-type', 'd', '-a', '(', *ignore_names_l, ')', '-prune', '-false', '-o']
+        # Also ignore any files with the names as well
+        ignore_file_args = ['-a', '-not', '(', *ignore_names_l, ')']
+
     return [
         *(['-L'] if follow else []),
         str(root),
+        *prune_dir_args,
         '-type', 'f',
+        *ignore_file_args
     ]
 
 
-def fdfind_args(root: Path, follow: bool) -> List[str]:
+def fdfind_args(root: Path, follow: bool, ignore: List[str]=[]) -> List[str]:
     from .config import extra_fd_args
+
+    ignore_args = []
+    if ignore:
+        # Add a statment that excludes the folder
+        ignore_args = [['--exclude', f'{n}'] for n in ignore]
+        # Flatten the list of lists
+        ignore_args_l = list(itertools.chain(*ignore_args))
+
     return [
         *extra_fd_args(),
+        *ignore_args_l,
         *(['--follow'] if follow else []),
         '--type', 'f',
         '.',
@@ -395,18 +446,29 @@ def fdfind_args(root: Path, follow: bool) -> List[str]:
     ]
 
 
-def traverse(root: Path, *, follow: bool=True) -> Iterable[Path]:
+def traverse(root: Path, *, follow: bool=True, ignore: List[str]=[]) -> Iterable[Path]:
     if not root.is_dir():
         yield root
         return
 
-    from subprocess import Popen, PIPE
+    # todo does windows even have symlinks??
+    if _is_windows:
+        # on windows could use 'forfiles'... but probably easier not to bother for now
+        # todo coild use followlinks=True? walk could end up in infinite loop?
+        for r, dirs, files in os.walk(root):
+            # Remove dirs specified in ignore (clone dirs() as we have to remove in place)
+            for i, d in enumerate(list(dirs)):
+                if d in ignore:
+                    del dirs[i]
+            yield from (Path(r) / f for f in files if f not in ignore)
+        return
 
-    cmd = ['find', *find_args(root, follow=follow)]
+    from .compat import Popen, PIPE
+    cmd = ['find', *find_args(root, follow=follow, ignore=ignore)]
     # try to use fd.. it cooperates well with gitignore etc, also faster than find
     for x in ('fd', 'fd-find', 'fdfind'): # has different names on different dists..
         if shutil.which(x):
-            cmd = [x, *fdfind_args(root, follow=follow)]
+            cmd = [x, *fdfind_args(root, follow=follow, ignore=ignore)]
             break
     else:
         warnings.warn("'fdfind' is recommended for the best indexing performance. See https://github.com/sharkdp/fd#installation. Falling back to 'find'")
@@ -434,7 +496,7 @@ def get_system_zone() -> str:
 
 
 @lru_cache(1)
-def get_system_tz():
+def get_system_tz() -> pytz.BaseTzInfo:
     zone = get_system_zone()
     try:
         return pytz.timezone(zone)
