@@ -5,7 +5,7 @@ Clones & indexes Git repositories (via sources.auto)
 
 from pathlib import Path
 import re
-from subprocess import check_call
+from ..compat import check_call
 from typing import Iterable
 
 from ..common import Extraction, PathIsh, get_tmpdir, slugify
