@@ -3,6 +3,7 @@ from contextlib import contextmanager
 from pathlib import Path
 from datetime import datetime
 from tempfile import TemporaryDirectory
+import os
 from subprocess import check_call, check_output
 from time import sleep
 from typing import NamedTuple, Optional, Iterator
@@ -20,7 +21,7 @@ from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.common.by import By
 
 
-from common import under_ci, skip_if_ci, uses_x, has_x
+from common import under_ci, uses_x, has_x
 from integration_test import index_hypothesis, index_local_chrome, index_urls
 from server_test import wserver
 from firefox_helper import open_extension_page
@@ -96,7 +97,7 @@ def get_hotkey(driver, cmd: str) -> str:
         # TODO remove hardcoding somehow...
         # perhaps should be extracted somewhere..
         cmd_map = {
-            Command.SHOW_DOTS        : 'Ctrl+Alt+v',
+            Command.MARK_VISITED     : 'Ctrl+Alt+v',
             '_execute_browser_action': 'Ctrl+Alt+e',
             'search'                 : 'Ctrl+Alt+h',
         }
@@ -209,7 +210,7 @@ def configure(
         set_position(driver, position)
 
     if blacklist is not None:
-        bl = driver.find_element_by_id('blacklist_id') # .find_element_by_tag_name('textarea')
+        bl = driver.find_element_by_id('global_excludelist_id') # .find_element_by_tag_name('textarea')
         bl.click()
         # ugh, that's hacky. presumably due to using Codemirror?
         bla = driver.switch_to_active_element()
@@ -294,7 +295,7 @@ class TestHelper(NamedTuple):
         self.command(Command.ACTIVATE)
 
     def mark_visited(self):
-        self.command(Command.SHOW_DOTS)
+        self.command(Command.MARK_VISITED)
 
     def wid(self) -> str:
         return get_window_id(self.driver)
@@ -350,12 +351,20 @@ def _test_helper(tmp_path, indexer, test_url: Optional[str], browser: Browser=FF
         yield TestHelper(driver=driver)
 
 class Command:
-    SHOW_DOTS = 'mark_visited'
+    MARK_VISITED = 'mark_visited'
     ACTIVATE  = '_execute_browser_action'
     SEARCH    = 'search'
 # TODO assert this against manifest?
 
 
+WITH_BROWSER_TESTS = 'WITH_BROWSER_TESTS'
+
+with_browser_tests = pytest.mark.skipif(
+    WITH_BROWSER_TESTS not in os.environ,
+    reason=f'set env var {WITH_BROWSER_TESTS}=true if you want to run this test',
+)
+
+
 def browsers(*br: Browser):
     if len(br) == 0:
         br = (FF, FFH, CH)
@@ -365,11 +374,11 @@ def browsers(*br: Browser):
     from functools import wraps
     def dec(f):
         if len(br) == 0:
-            dd = pytest.mark.skip('Filtered out all browsers (because of no GUI/non-interactive mode)')
+            dec_ = pytest.mark.skip('Filtered out all browsers (because of no GUI/non-interactive mode)')
         else:
-            dd = pytest.mark.parametrize('browser', br, ids=lambda b: b.dist.replace('-', '_') + ('_headless' if b.headless else ''))
-        @pytest.mark.with_browser
-        @dd
+            dec_ = pytest.mark.parametrize('browser', br, ids=lambda b: b.dist.replace('-', '_') + ('_headless' if b.headless else ''))
+        @with_browser_tests
+        @dec_
         @wraps(f)
         def ff(*args, **kwargs):
             return f(*args, **kwargs)
@@ -534,7 +543,7 @@ def test_chrome_visits(tmp_path, browser):
 
 
 @browsers(FF, CH)
-def test_show_dots(tmp_path, browser):
+def test_show_visited_marks(tmp_path, browser):
     visited = {
         'https://en.wikipedia.org/wiki/Special_linear_group': None,
         'http://en.wikipedia.org/wiki/Unitary_group'        : None,
@@ -542,8 +551,8 @@ def test_show_dots(tmp_path, browser):
     }
     test_url = "https://en.wikipedia.org/wiki/Symplectic_group"
     with _test_helper(tmp_path, index_urls(visited), test_url, show_dots=True, browser=browser) as helper:
-        trigger_command(helper.driver, Command.SHOW_DOTS)
-        confirm("You should see dots near special linear group, Unitary group, Transpose")
+        trigger_command(helper.driver, Command.MARK_VISITED)
+        confirm("You should see visited marks near special linear group, Unitary group, Transpose")
 
 
 @browsers(FF, CH)
@@ -671,7 +680,7 @@ def trigger_sidebar_search(driver):
 @browsers(FF, CH)
 def test_duplicate_background_pages(tmp_path, browser):
     url = PYTHON_DOC_URL
-    with _test_helper(tmp_path, index_urls({}), url, browser=browser) as helper:
+    with _test_helper(tmp_path, index_urls({'whatever.coom': '123'}), url, browser=browser) as helper:
         driver = helper.driver
 
         trigger_command(driver, Command.ACTIVATE)
