@@ -15,10 +15,10 @@ import pytest # type: ignore
 from pytest import mark # type: ignore
 
 
-from common import skip_if_ci, tdata
+from common import tdata
 from config_tests import with_config
 
-from promnesia.common import Visit, Indexer, Loc, Res, DbVisit
+from promnesia.common import Visit, Indexer, Loc, Res, DbVisit, _is_windows
 
 # TODO need to expire dbcache in tests..
 
@@ -155,7 +155,7 @@ def test_takeout_new_zip(adhoc_config) -> None:
     assert_got_tzinfo(visits)
 
 
-@skip_if_ci("TODO try triggering firefox on CI? not sure if that's possible...")
+@skip("TODO not sure how to trigger firefox on CI...")
 def test_backup_firefox(tmp_path):
     tdir = Path(tmp_path)
     path = backup_db.backup_history('firefox', to=tdir, profile='*release*')
@@ -254,12 +254,14 @@ FILTERS = [
         assert len(visits) == 4
 
 
+@pytest.mark.skipif(_is_windows, reason="no grep on windows")
 def test_custom() -> None:
     import promnesia.sources.shellcmd as custom_gen
 
     visits = as_visits(W(
         custom_gen.index,
-        """grep -Eo -r --no-filename '(http|https)://\S+' """ + tdata('custom'),
+        # meh. maybe should deprecate plain string here...
+        """grep -Eo -r --no-filename (http|https)://\S+ """ + tdata('custom'),
     ))
     # TODO I guess filtering of equivalent urls should rather be tested on something having context (e.g. org mode)
     assert len(visits) == 5
@@ -395,6 +397,4 @@ def test_merge_all_from(tmp_path):
 if __name__ == '__main__':
     pytest.main([__file__])
 
-# TODO mark tests with @skip_if_ci
-
 # TODO once I integrate test for db population, test chrome/firefox extractors
