@@ -1,4 +1,5 @@
 from itertools import groupby
+import os
 
 from promnesia.sources import auto
 
@@ -31,6 +32,7 @@ def test_json() -> None:
     # TODO not sure if they deserve separate visits..
     [v1, v2] = mm[sa2464]
     assert v1.context == 'list::yyy::given_url'
+    # todo not sure if editor:// work on Windows
     assert v1.locator.href.startswith('editor://')
     assert v1.locator.href.endswith('pocket.json')
     # TODO line number?
@@ -45,7 +47,7 @@ def test_auto() -> None:
     }.issubset(mm.keys())
 
     [v] = mm[org_link]
-    assert v.locator.title == 'orgs/file.org:14'
+    assert v.locator.title == 'orgs' + os.sep + 'file.org:14' # meh
     assert v.locator.href.endswith('file.org:14')
     assert "xxx /r/cpp" in v.context
     assert "I've enjoyed [Chandler Carruth's" in v.context
